needed_packages <- c(
  "shiny"
, "shinythemes"
, "shinydashboard"
)

## Check if the packages are installed. If they are not install them, then load them
if (length(setdiff(needed_packages, rownames(installed.packages()))) > 0) {
  install.packages(setdiff(needed_packages, rownames(installed.packages())))  
}

lapply(needed_packages, require, character.only = TRUE)

# Define UI for slider demo application
#shinyUI(
fluidPage(
  
  ## theme
   theme = shinytheme("lumen")
  
  ## Custom styling of any widgets
  , tags$style(" .checkbox {font-size: 18px}")
  
  ## Set up the page with a sidebar
  , pageWithSidebar(
  
  ## Title
  headerPanel("A General Vector-Borne Disease Model")
  
  ## Sidebar with all parameter values
    , sidebarPanel(
      
  ## Would like a conditional submitButton but to get this to work it seems I need a conditional action button
   ## and to change around my code a lot, so skip for now
#     conditionalPanel(
#        condition = "input.uncer_mos_temp == true || input.uncer_mos_human == true"
#     ,  submitButton("Run ODE", icon("refresh"))
#   )
    
     tags$h4("Parameter Values")
      
    , radioButtons(
         "intervention", h5("Consider an intervention?")
         , choices = list(
           "None"    = "None"
         , "mu_m"    = "mu_m"
         , "mu_a"    = "mu_a"
         , "k"       = "k"
         , "beta_mh" = "beta_mh"
         , "phi"     = "phi"
         , "eta_h"   = "eta_h")
         , selected  = "None")
      
    , conditionalPanel(
        condition = "input.mos_temp_dep == true"
    , sliderInput(
      "temp", "Temperature (C):"
    , min   = 16
    , max   = 36
    , value = 26
    , step  = 1)
    )
      
############      
### Parameters always available
############
    
    , sliderInput(
      "N_0", "Population Size:"
    , min   = 200
    , max   = 400000
    , value = 1200
    , step  = 1000)
    
    , sliderInput(
      "I_h0", "Initial proportion of humans Infected:"
    , min   = 0
    , max   = 0.5
    , value = .01
    , step  = .01)
    
    , sliderInput(
      "R_h0", "Initial proportion of humans Recovered:"
    , min   = 0
    , max   = 0.5
    , value = 0
    , step  = .01)
    
    , sliderInput(
      "np", "Number of time periods:"
    , min   = 10
    , max   = 360
    , value = 90
    , step  = 5)
      
    , sliderInput(
      "k", "Carrying capcity of aquatic stage mosquitoes per human:"
    , min   = 0.5
    , max   = 10
    , value = 3
    , step  = 0.5) 
    
    , sliderInput(
      "m_per_h", "Pre-epidemic number of adult (female) mosquitoes per human:"
    , min   = 0.5
    , max   = 10
    , value = 3
    , step  = 0.5)  
      
############      
### Parameters available only when temp dependence == FALSE
############
    
    , conditionalPanel(
        condition = "input.mos_temp_dep == false"
      
    , sliderInput(
      "B", "Mosquito biting rate:"
    , min   = 0.1
    , max   = 1
    , value = 0.6
    , step  = 0.1)
      
    , sliderInput(
      "beta_mh", "Transmition probability mosquito to host:"
    , min   = 0.05
    , max   = 0.85
    , value = 0.35
    , step  = 0.10)

    , sliderInput(
      "phi", "Number of eggs at each deposit per adult mosquito:"
    , min   = 2
    , max   = 12
    , value = 6
    , step  = 2)
    
    , sliderInput(
      "mu_a", "Aquatic stage mosquito mortality rate:"
    , min   = 0.08
    , max   = 1
    , value = 0.25
    , step  = 0.08)
    
    , sliderInput(
      "mu_m", "Adult stage mosquito mortality rate:"
    , min   = 0.03
    , max   = 0.2
    , value = 0.1
    , step  = 0.03)
      
    , sliderInput(
      "eta_a", "Mosquito maturation rate from larvae to adult:"
    , min   = 0.02
    , max   = 0.4
    , value = 0.08
    , step  = 0.06)
      
    )
  
#    , conditionalPanel(
#        condition = "input.mos_temp_dep == false || input.mos_human_dep == false"
      
    ## !*! Biting rate should go here, but this conditional panel isn't working for whatever reason
      
  #     )
    
############      
### Disease AND Temperature dependent parameters 
############
      
 ## !*! Should be beta_mh but haven't gotten here yet
    
############      
### Disease dependent parameters 
############
      
    , conditionalPanel(     
        condition = "input.hide_dis_parms == false" 

    , sliderInput(
      "beta_hm", "Transmition probability host to mosquito:"
    , min   = 0.05
    , max   = 0.85
    , value = 0.35
    , step  = 0.10)
    
    , sliderInput(
      "eta_h", "Human recovery rate:"
    , min   = 0.10
    , max   = 0.7
    , value = 0.3
    , step  = 0.1)
      
    , sliderInput(
      "alpha_h", "Disease induced host mortality rate:"
    , min   = 1E-5
    , max   = 0.1
    , value = 1E-4
    , step  = 0.005)
      
    , sliderInput(
      "gamma_m", "Mosquito exit rate from latent period:"
    , min   = 0.10
    , max   = 0.7
    , value = 0.2
    , step  = 0.1) 
     
    , sliderInput(
      "gamma_h", "Host exit rate from latent period:"
    , min   = 0.01
    , max   = 0.6
    , value = 0.2
    , step  = 0.05) 

    , sliderInput(
      "psi_h", "Asymptomatic infection probability ratio:"
    , min   = 0.0
    , max   = 1.0
    , value = 0.5
    , step  = 0.1)

    , sliderInput(
      "omega_Ah", "Proportion of infected hosts asymptomatic:"
    , min   = 0.0
    , max   = 1.0
    , value = 0.5
    , step  = 0.1)
      
    , sliderInput(
      "delta_h", "Waning rate of immunity:"
    , min   = 1E-5
    , max   = 0.01
    , value = 1E-4
    , step  = 0.005)
      
     , radioButtons(
         "omega_Eh", h5("Proportion of hosts entering exposed category")
         , choices = list(
           "1" = 1
         , "0" = 0)
         , selected  = "0")   
  
     , radioButtons(
         "omega_Em", h5("Proportion of mosquitoes entering exposed category")
         , choices = list(
           "1" = 1
         , "0" = 0)
         , selected  = "0") 
      
    )
    
    , br()
    
    , h5("Created by:")
    
    , tags$a("Morgan Kain: Natural Capitol Project Stanford University"
    , href="http://www.morgankain.weebly.com")
    
    , h5("For Details contact me at:
kainm@stanford.edu;
morganpkain@gmail.com")
    
    )
    
    ## Primary panel for a few more choices and output
    , mainPanel(

    ## Box to hold a series of optional changes to the model, which change what parameters users can alter
      box(width = 12
    
    , textInput("dis_type", label = h5("What disease? (None, DNV, CHIKV, Malaria)"), value = "None", width = '800px')
        
#    , conditionalPanel(     
#        condition = "input.dis_type != None" 
#    ,
    , checkboxInput("hide_dis_parms", "Hide unused parameters?", width = '800px')    
#      )
        
    , checkboxInput("uncer", "Consider uncertainty in parameters?", width = '800px')
      
    , conditionalPanel(
        condition = "input.uncer == true"
     , textInput("uncer_type", label = h5("What parameters ('parameter name' or 'all')"), value = "none", width = '800px')
     , numericInput("uncer_runs", label = h5("Number of samples"), value = 10)
     , sliderInput(
      "uncer_logsd", "uncer_logsd (prop to mean):"
    , min   = 0.01
    , max   = 0.3
    , value = 0.1
    , step  = 0.01)
   )

    , checkboxInput("mos_temp_dep", "Temperature dependent mosquito parameters?", width = '800px')
    
    , conditionalPanel(
        condition = "input.mos_temp_dep == true"
      ,  textInput("mosq_species", label = h5("What mosquito species? (Genus species) or (Genus sp) or (NA NA)"), value = "NA NA", width = '800px')
       , radioButtons(
         "temp_loc", h5("Global Environment")
         , choices = list(
           "Tropical"  = "tropical"
         , "Temperate" = "temperate")
         , selected = "tropical")
    )
        
   , checkboxInput("mos_human_dep", "Human population dependent mosquito parameters?", width = '800px')
        
      )
     
    ## Box to for the output 
  , box(width = 12,
      
  tabsetPanel(type = "tabs"
    , tabPanel("Plot"
      , plotOutput("graph1")
      , plotOutput("graph2"))
    , tabPanel("Summary"
      , verbatimTextOutput("summary"))
#    , tabPanel("Error Message Info"
#      , verbatimTextOutput("debug"))
    , tabPanel("Model Details"
       , 
      h4("Click the link below to see details about the model. Click refresh at the top of this page to return.")
    , tags$a(href='server_readme.html', 'Model Details')
      )
    , tabPanel("Notes"
      , 
      h3("Think the bones are pretty set and parmaeter values are ok, but need lots more time devoted to establishing outcomes, expanding interventions, exploring the model etc.:")
    , h4("1) Dig a bit more in the lit to define the parameter space that would be explored for any given disease")
    , h4("2) Can we cover diseases other than DNV, CHIKV, ZIKA, Malaria?")
    , h4("3) R0 printout for each run to understand how changing parameter values are affecting R0")
    , h4("4) Lots of temperate mosquito response parameters needed")
    , h4("5) Figure out the human dependence parameters")
    , h4("6) Some very simple and loose canned interventions are in place, but what kind of NatCap-style scenarios would we want to build in?")
    
    , h3("A few things that seem probably to be too much")
    , h4("1) Anything spatial")
    , h4("2) Multiple host diseases / zoonotic diseases with spillover into humans")      
    , h4("3) Uncertainty in a better way then running the ODE over some defined parameter ranges"))
    , tabPanel("Download Current Run"
    , downloadButton("datadown", "Download"))
    )
   )
  )
 )
)



